bayespy.inference.vmp.nodes.wishart.WishartDistribution.plates_to_parent
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.wishart

.. automethod:: WishartDistribution.plates_to_parent